.. _from_marginal:

.. currentmodule :: gcmpy

Creating random networks from marginal data 
===========================================================

In this section, we examine how to use ``gcmpy`` to create random graphs from 
marginal degree distributions. 

